@@ -3,5 +3,6 @@ Main module containing the MirthAPI class for interacting with a Mirth instance
 """
 
 from .mirth import MirthAPI
+from .channels import Channel
 
-__all__ = ["MirthAPI"]
+__all__ = ["MirthAPI", "Channel"]
