@@ -12,6 +12,7 @@ from typing import (
     Iterable,
     List,
     Optional,
+    OrderedDict,
     Set,
     Type,
     TypeVar,
@@ -61,6 +62,14 @@ class MirthBaseModel(BaseModel):
         alias_generator = _to_camel
 
 
+class XMLDict(OrderedDict):
+    """Custom class used to differentiate general OrderedDict
+    from dictionaries coming directly from xmltodict.
+
+    Functionally, this is just an alias of OrderedDict
+    """
+
+
 class XMLBaseModel(MirthBaseModel):
     """
     Base model for parsing and serialising to XML data.
@@ -121,14 +130,14 @@ class XMLBaseModel(MirthBaseModel):
                     b,
                     force_list=force_list,
                     encoding="utf-8" if encoding == "utf8" else encoding,
-                    dict_constructor=dict,
+                    dict_constructor=XMLDict,
                 )
                 return cls.parse_obj(obj)
         except (
             ValueError,
             TypeError,
             UnicodeDecodeError,
-            xml.parsers.expat.ExpatError,
+            xml.parsers.expat.ExpatError,  # pylint: disable=no-member
         ) as e:
             raise ValidationError([ErrorWrapper(e, loc="__obj__")], cls) from e
         return super().parse_raw(  # type: ignore
@@ -231,28 +240,133 @@ class ConnectorMessageData(MirthBaseModel):
     channel_id: UUID
     content: Optional[str]
     content_type: str
-    data_type: str
+    data_type: Optional[str]
     encrypted: bool
     message_id: str
     message_data_id: Optional[str]
 
 
+def _xml_map_item_to_dict(in_dict: Dict[str, Any]):
+    if not isinstance(in_dict, XMLDict):
+        raise TypeError(
+            f"XML map must be passed as an XMLDict. Instead got {type(in_dict)}"
+        )
+    if not "string" in in_dict.keys():
+        raise ValueError("XML map requires at least one string key")
+
+    # XML map parsing only works if we have one or two XML keys.
+    # One key means both actual key and value are the same type (string)
+    # Two keys means actual key and value are different types.
+    # Actual key must always be string, actual value can be anything,
+    # but we'll be turning it into a string since we're just grabbing XML text
+    if len(in_dict.keys()) not in (1, 2):
+        raise ValueError("XML map can only contain a maximum of 2 keys")
+
+    # If we have one key, both key and value are strings
+    if len(in_dict.keys()) == 1:
+        # In this case, we NEED a second value under the "string" key,
+        # corresponding to the actual value
+        if len(in_dict["string"]) != 2:
+            raise ValueError("XML map expected two items exactly under the string key")
+        actual_key = in_dict["string"][0]
+        actual_val = in_dict["string"][1]
+
+    # The only other option is having two XML keys.
+    # In this case, the string key describes the actual map key,
+    # and the other key describes the type of it's corresponding value.
+    # We don't care about the XML value type, so we just want to extract
+    # the map key, and whatever the actual value is.
+    else:
+        if not isinstance(in_dict["string"], str):
+            # In this case our string XML key MUST contain a single string
+            # which corresponds to the actual key we want to return
+            raise ValueError("XML map string key must contain a single string value")
+        values: List[str] = list(in_dict.values())
+        actual_key = values[0]
+        actual_val = values[1]
+
+    out = {actual_key: actual_val}
+    return out
+
+
+def _xml_map_to_dict(in_data: Union[Dict[str, Any], List[Dict[str, Any]]]):
+    out: Dict[str, str] = {}
+    # If a list of items is passed in, then we want to merge
+    # them into a single dictionary. The xmltodict module will
+    # create lists where we want a map, so we just manually handle
+    # this conversion here.
+    if isinstance(in_data, (list, tuple)):
+        for item in in_data:
+            out.update(_xml_map_item_to_dict(item))
+        return out
+    return _xml_map_item_to_dict(in_data)
+
+
+class MetaDataMap(Dict):
+    """
+    Custom field class for a Mirth API MetaDataMap object,
+    with a validator to convert xmltodict output into a useful
+    dictionary-like object.
+    """
+
+    @classmethod
+    def __get_validators__(cls):
+        yield cls.validate
+
+    @classmethod
+    def validate(cls, value):
+        """
+        Convert xmltodict output into a tidy Python dictionary
+
+        We need to run a conversion from XMLDict to Dict if,
+        and only if, the value itself is an XMLDict, or the
+        value is a list of XMLDict elements.
+
+        We need to run this check as the model will be used
+        both for parsing the XML data returned by the Mirth API,
+        but also for downstream validation, such as using this
+        model within a FastAPI application.
+        """
+        if isinstance(value, XMLDict) or all(
+            isinstance(element, XMLDict) for element in value
+        ):
+            return _xml_map_to_dict(value)
+        return value
+
+
 class ConnectorMessageModel(XMLBaseModel):
     """Mirth API connectorMessage object"""
 
     __root_element__ = "connectorMessage"
-    chain_id: str
+    chain_id: int
+    order_id: int
     server_id: UUID
     channel_id: str
+
     channel_name: str
     connector_name: str
 
     message_id: str
-    error_code: str
+    error_code: int
     send_attempts: int
 
     raw: Optional[ConnectorMessageData]
     encoded: Optional[ConnectorMessageData]
+    sent: Optional[ConnectorMessageData]
+    response: Optional[ConnectorMessageData]
+
+    meta_data_map: Optional[MetaDataMap]
+
+    @validator("meta_data_map", pre=True)
+    def strip_metadatamap_entry_roots(cls, value):  # pylint: disable=no-self-use
+        """
+        Extract the actual metaDataMap elements from the parsed-XML dictionary.
+        The 'metaDataMap' element contains an element 'entry', which contains
+        a list of map elements which we actually want.
+        """
+        if value and "entry" in value:
+            return value["entry"]
+        return value
 
 
 class ChannelMessageModel(XMLBaseModel):
